# Python api for Statistics Canada New Data Model (NDM)

[![Tests](https://github.com/ianepreston/stats_can/workflows/Tests/badge.svg)](https://github.com/ianepreston/stats_can/actions?workflow=Tests)
[![Documentation Status](https://readthedocs.org/projects/stats-can/badge/?version=latest)](https://stats-can.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/ianepreston/stats_can/branch/master/graph/badge.svg)](https://codecov.io/gh/ianepreston/stats_can)
[![PyPI version](https://badge.fury.io/py/stats-can.svg)](https://badge.fury.io/py/stats-can)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/stats_can/badges/version.svg)](https://anaconda.org/conda-forge/stats_can)

API documentation for StatsCan can be found here: https://www.statcan.gc.ca/eng/developers/wds

If you're looking for Table/Vector IDs to use in the app you can find them through this:
https://www150.statcan.gc.ca/n1/en/type/data

Anaconda package here:
https://anaconda.org/conda-forge/stats_can


Documentation here:
https://stats-can.readthedocs.io/en/latest/
